searchData={"items":[{"type":"module","title":"FinancialFormulas","doc":"","ref":"FinancialFormulas.html"},{"type":"function","title":"FinancialFormulas.annual_percentage_yield/2","doc":"Calculates the annual percentage yield (APY) of an investment.\n\nThe annual percentage yield is the the rate of interest that is earned when taking into consideration the effect of compounding.","ref":"FinancialFormulas.html#annual_percentage_yield/2"},{"type":"function","title":"Formula - FinancialFormulas.annual_percentage_yield/2","doc":"(1 + interest_rate / number_of_times_compounded) ^ number_of_times_compounded - 1","ref":"FinancialFormulas.html#annual_percentage_yield/2-formula"},{"type":"function","title":"Required - FinancialFormulas.annual_percentage_yield/2","doc":"* `nominal_interest_rate` - The nominal interest rate of the investment.\n* `number_of_times_compounded` - The number of times the interest is compounded per year.","ref":"FinancialFormulas.html#annual_percentage_yield/2-required"},{"type":"function","title":"Examples - FinancialFormulas.annual_percentage_yield/2","doc":"iex> FinancialFormulas.annual_percentage_yield(0.025, 12)\n0.025288456983290075","ref":"FinancialFormulas.html#annual_percentage_yield/2-examples"},{"type":"function","title":"FinancialFormulas.asset_to_sales_ratio/2","doc":"Calculates the asset to sales ratio of an entity.","ref":"FinancialFormulas.html#asset_to_sales_ratio/2"},{"type":"function","title":"Formula - FinancialFormulas.asset_to_sales_ratio/2","doc":"total_asset / total_sales","ref":"FinancialFormulas.html#asset_to_sales_ratio/2-formula"},{"type":"function","title":"Required - FinancialFormulas.asset_to_sales_ratio/2","doc":"* `total_assets` - The total assets of the entity.\n* `sales_revenue` - The sales/revenue of the entity.","ref":"FinancialFormulas.html#asset_to_sales_ratio/2-required"},{"type":"function","title":"Examples - FinancialFormulas.asset_to_sales_ratio/2","doc":"iex> FinancialFormulas.asset_to_sales_ratio(100000, 50000)\n2.0","ref":"FinancialFormulas.html#asset_to_sales_ratio/2-examples"},{"type":"function","title":"FinancialFormulas.asset_turnover_ratio/2","doc":"Calculates the asset turnover ratio of an entity.","ref":"FinancialFormulas.html#asset_turnover_ratio/2"},{"type":"function","title":"Formula - FinancialFormulas.asset_turnover_ratio/2","doc":"total_sales / total_asset","ref":"FinancialFormulas.html#asset_turnover_ratio/2-formula"},{"type":"function","title":"Required - FinancialFormulas.asset_turnover_ratio/2","doc":"* `sales_revenue` - The sales/revenue of the entity.\n* `total_asset` - The total assets of the entity.","ref":"FinancialFormulas.html#asset_turnover_ratio/2-required"},{"type":"function","title":"Examples - FinancialFormulas.asset_turnover_ratio/2","doc":"iex> FinancialFormulas.asset_turnover_ratio(50000, 100000)\n0.5","ref":"FinancialFormulas.html#asset_turnover_ratio/2-examples"},{"type":"function","title":"FinancialFormulas.average_collection_period/1","doc":"Calculates the average collection period of an entity.","ref":"FinancialFormulas.html#average_collection_period/1"},{"type":"function","title":"Formula - FinancialFormulas.average_collection_period/1","doc":"365 / receivables_turnover_ratio","ref":"FinancialFormulas.html#average_collection_period/1-formula"},{"type":"function","title":"Required - FinancialFormulas.average_collection_period/1","doc":"* `receivables_turnover_ratio` - The receivables turnover ratio of the entity.","ref":"FinancialFormulas.html#average_collection_period/1-required"},{"type":"function","title":"Examples - FinancialFormulas.average_collection_period/1","doc":"iex> FinancialFormulas.average_collection_period(10)\n36.5","ref":"FinancialFormulas.html#average_collection_period/1-examples"},{"type":"function","title":"FinancialFormulas.average_inventory/3","doc":"Calculates the average inventory of an entity.","ref":"FinancialFormulas.html#average_inventory/3"},{"type":"function","title":"Formula - FinancialFormulas.average_inventory/3","doc":"(ending_inventory + beginning_inventory) / number_of_periods","ref":"FinancialFormulas.html#average_inventory/3-formula"},{"type":"function","title":"Required - FinancialFormulas.average_inventory/3","doc":"* `ending_inventory` - The ending inventory of the entity.\n* `beginning_inventory` - The beginning inventory of the entity.","ref":"FinancialFormulas.html#average_inventory/3-required"},{"type":"function","title":"Optional - FinancialFormulas.average_inventory/3","doc":"* `number_of_periods` - The number of periods. Defaults to 2.","ref":"FinancialFormulas.html#average_inventory/3-optional"},{"type":"function","title":"Examples - FinancialFormulas.average_inventory/3","doc":"iex> FinancialFormulas.average_inventory(100, 50)\n75.0\n\niex> FinancialFormulas.average_inventory(100, 50, 3)\n50.0","ref":"FinancialFormulas.html#average_inventory/3-examples"},{"type":"function","title":"FinancialFormulas.average_inventory_period/2","doc":"Calculates the average inventory period of an entity.","ref":"FinancialFormulas.html#average_inventory_period/2"},{"type":"function","title":"Formula - FinancialFormulas.average_inventory_period/2","doc":"number_of_days_in_period / inventory_turnover","ref":"FinancialFormulas.html#average_inventory_period/2-formula"},{"type":"function","title":"Required - FinancialFormulas.average_inventory_period/2","doc":"* `inventory_turnover` - The inventory turnover of the entity.","ref":"FinancialFormulas.html#average_inventory_period/2-required"},{"type":"function","title":"Optional - FinancialFormulas.average_inventory_period/2","doc":"* `days_in_period` - The number of days in the period. Defaults to 365.","ref":"FinancialFormulas.html#average_inventory_period/2-optional"},{"type":"function","title":"Examples - FinancialFormulas.average_inventory_period/2","doc":"iex> FinancialFormulas.average_inventory_period(10)\n36.5\n\niex> FinancialFormulas.average_inventory_period(10, 180)\n18.0","ref":"FinancialFormulas.html#average_inventory_period/2-examples"},{"type":"function","title":"FinancialFormulas.average_payment_period/3","doc":"Calculates the average payment period of an entity.","ref":"FinancialFormulas.html#average_payment_period/3"},{"type":"function","title":"Formula - FinancialFormulas.average_payment_period/3","doc":"average_accounts_payable / (credit_purchases / days_in_period)","ref":"FinancialFormulas.html#average_payment_period/3-formula"},{"type":"function","title":"Required - FinancialFormulas.average_payment_period/3","doc":"* `average_accounts_payable` - The average accounts payable of the entity.\n* `credit_purchases` - The credit purchases of the entity.","ref":"FinancialFormulas.html#average_payment_period/3-required"},{"type":"function","title":"Optional - FinancialFormulas.average_payment_period/3","doc":"* `days_in_period` - The number of days in the period.","ref":"FinancialFormulas.html#average_payment_period/3-optional"},{"type":"function","title":"Examples - FinancialFormulas.average_payment_period/3","doc":"iex> FinancialFormulas.average_payment_period(23000, 100000)\n83.95\n\niex> FinancialFormulas.average_payment_period(100, 200, 180)\n90.0","ref":"FinancialFormulas.html#average_payment_period/3-examples"},{"type":"function","title":"FinancialFormulas.bid_ask_spread/2","doc":"Calculates the bid ask spread of a security.","ref":"FinancialFormulas.html#bid_ask_spread/2"},{"type":"function","title":"Formula - FinancialFormulas.bid_ask_spread/2","doc":"ask_price - bid_price","ref":"FinancialFormulas.html#bid_ask_spread/2-formula"},{"type":"function","title":"Required - FinancialFormulas.bid_ask_spread/2","doc":"* `ask_price` - The ask price of the security.\n* `bid_price` - The bid price of the security.","ref":"FinancialFormulas.html#bid_ask_spread/2-required"},{"type":"function","title":"Example - FinancialFormulas.bid_ask_spread/2","doc":"iex> FinancialFormulas.bid_ask_spread(10, 8)\n2","ref":"FinancialFormulas.html#bid_ask_spread/2-example"},{"type":"function","title":"FinancialFormulas.bond_equivalent_yield/3","doc":"Calculates the bond equivalent yield of a bond.","ref":"FinancialFormulas.html#bond_equivalent_yield/3"},{"type":"function","title":"Formula - FinancialFormulas.bond_equivalent_yield/3","doc":"(face_value - bond_price) / bond_price * (365 / days)","ref":"FinancialFormulas.html#bond_equivalent_yield/3-formula"},{"type":"function","title":"Required - FinancialFormulas.bond_equivalent_yield/3","doc":"* `face_value` - The face value of the bond.\n* `purchase_price` - The purchase price of the bond.","ref":"FinancialFormulas.html#bond_equivalent_yield/3-required"},{"type":"function","title":"Optional - FinancialFormulas.bond_equivalent_yield/3","doc":"* `days_to_maturity` - The number of days until the bond matures. Defaults to 365.","ref":"FinancialFormulas.html#bond_equivalent_yield/3-optional"},{"type":"function","title":"Examples - FinancialFormulas.bond_equivalent_yield/3","doc":"iex> FinancialFormulas.bond_equivalent_yield(110, 100, 180)\n0.20277777777777778\n\niex> FinancialFormulas.bond_equivalent_yield(110, 100)\n0.1","ref":"FinancialFormulas.html#bond_equivalent_yield/3-examples"},{"type":"function","title":"FinancialFormulas.book_value_per_share/3","doc":"Calculates the book value per share of an entity.","ref":"FinancialFormulas.html#book_value_per_share/3"},{"type":"function","title":"Formula - FinancialFormulas.book_value_per_share/3","doc":"(total_common_equity - perferred_equity) / weighted_average_number_of_shares_outstanding","ref":"FinancialFormulas.html#book_value_per_share/3-formula"},{"type":"function","title":"Required - FinancialFormulas.book_value_per_share/3","doc":"* `shareholders_equity` - The shareholders equity of the entity.\n* `perferred_equity` - The perferred equity of the entity.\n* `weighted_average_number_of_shares_outstanding` - The weighted average number of shares outstanding of the entity.","ref":"FinancialFormulas.html#book_value_per_share/3-required"},{"type":"function","title":"Examples - FinancialFormulas.book_value_per_share/3","doc":"iex> FinancialFormulas.book_value_per_share(100, 10, 10)\n9.0","ref":"FinancialFormulas.html#book_value_per_share/3-examples"},{"type":"function","title":"FinancialFormulas.capital_asset_pricing_model/3","doc":"Calculates the capital asset pricing model (CAPM).","ref":"FinancialFormulas.html#capital_asset_pricing_model/3"},{"type":"function","title":"Formula - FinancialFormulas.capital_asset_pricing_model/3","doc":"risk_free_rate + beta * (expected_market_return - risk_free_rate)","ref":"FinancialFormulas.html#capital_asset_pricing_model/3-formula"},{"type":"function","title":"Required - FinancialFormulas.capital_asset_pricing_model/3","doc":"* `risk_free_rate` - The risk free rate.\n* `beta` - The beta of the investment.\n* `market_retrun` - The return on the market.","ref":"FinancialFormulas.html#capital_asset_pricing_model/3-required"},{"type":"function","title":"Examples - FinancialFormulas.capital_asset_pricing_model/3","doc":"iex> FinancialFormulas.capital_asset_pricing_model(0.03, 0.8, 0.1)\n0.08600000000000001","ref":"FinancialFormulas.html#capital_asset_pricing_model/3-examples"},{"type":"function","title":"FinancialFormulas.capital_gains_yield/2","doc":"Calculates the capital gains yield of an investment.","ref":"FinancialFormulas.html#capital_gains_yield/2"},{"type":"function","title":"Formula - FinancialFormulas.capital_gains_yield/2","doc":"(final_price - initial_price) / initial_price","ref":"FinancialFormulas.html#capital_gains_yield/2-formula"},{"type":"function","title":"Required - FinancialFormulas.capital_gains_yield/2","doc":"* `initial_price` - The initial price of the investment.\n* `final_price` - The final price of the investment.","ref":"FinancialFormulas.html#capital_gains_yield/2-required"},{"type":"function","title":"Examples - FinancialFormulas.capital_gains_yield/2","doc":"iex> FinancialFormulas.capital_gains_yield(10, 12)\n0.2","ref":"FinancialFormulas.html#capital_gains_yield/2-examples"},{"type":"function","title":"FinancialFormulas.cash_conversion_cycle/3","doc":"Calculates the cash conversion cycle of an entity.","ref":"FinancialFormulas.html#cash_conversion_cycle/3"},{"type":"function","title":"Formula - FinancialFormulas.cash_conversion_cycle/3","doc":"days_inventory_outstanding + days_sales_outstanding - days_payable_outstanding","ref":"FinancialFormulas.html#cash_conversion_cycle/3-formula"},{"type":"function","title":"Required - FinancialFormulas.cash_conversion_cycle/3","doc":"* `days_inventory_outstanding` - The days inventory outstanding of the entity.\n* `days_sales_outstanding` - The days sales outstanding of the entity.\n* `days_payable_outstanding` - The days payable outstanding of the entity.","ref":"FinancialFormulas.html#cash_conversion_cycle/3-required"},{"type":"function","title":"Examples - FinancialFormulas.cash_conversion_cycle/3","doc":"iex> FinancialFormulas.cash_conversion_cycle(82, 34, 66)\n50","ref":"FinancialFormulas.html#cash_conversion_cycle/3-examples"},{"type":"function","title":"FinancialFormulas.compound_interest/4","doc":"Calculates compound interest","ref":"FinancialFormulas.html#compound_interest/4"},{"type":"function","title":"Formula - FinancialFormulas.compound_interest/4","doc":"principal * (1 + rate_per_period / number_of_periods_per_year) ^ (number_of_periods_per_year * number_of_years)","ref":"FinancialFormulas.html#compound_interest/4-formula"},{"type":"function","title":"Required - FinancialFormulas.compound_interest/4","doc":"* `principal` - The principal amount.\n* `rate_per_period` - The interest rate per period.\n* `number_of_years` - The number of years.\n* `number_of_periods_per_year` - The number of periods per year. Defaults to 12.","ref":"FinancialFormulas.html#compound_interest/4-required"},{"type":"function","title":"Examples - FinancialFormulas.compound_interest/4","doc":"iex> FinancialFormulas.compound_interest(5000, 0.05, 10)\n8235.0474884514\n\niex> FinancialFormulas.compound_interest(5000, 0.05, 10, 12)\n8235.0474884514","ref":"FinancialFormulas.html#compound_interest/4-examples"},{"type":"function","title":"FinancialFormulas.continuous_compounding/3","doc":"Calculates the continuous compounding of an investment.","ref":"FinancialFormulas.html#continuous_compounding/3"},{"type":"function","title":"Formula - FinancialFormulas.continuous_compounding/3","doc":"principal * e ^ (rate * time)","ref":"FinancialFormulas.html#continuous_compounding/3-formula"},{"type":"function","title":"Required - FinancialFormulas.continuous_compounding/3","doc":"* `principal` - The principal amount.\n* `interest_rate` - The interest rate.\n* `time` - The time.","ref":"FinancialFormulas.html#continuous_compounding/3-required"},{"type":"function","title":"Examples - FinancialFormulas.continuous_compounding/3","doc":"iex> FinancialFormulas.continuous_compounding(3000, 0.07, 5)\n4257.202645779772","ref":"FinancialFormulas.html#continuous_compounding/3-examples"},{"type":"function","title":"FinancialFormulas.contribution_margin/2","doc":"Calculates the contribution margin","ref":"FinancialFormulas.html#contribution_margin/2"},{"type":"function","title":"Formula - FinancialFormulas.contribution_margin/2","doc":"total_sales_revenue - variable_costs","ref":"FinancialFormulas.html#contribution_margin/2-formula"},{"type":"function","title":"Required - FinancialFormulas.contribution_margin/2","doc":"* `total_sales_revenue` - The total sales revenue\n* `variable_costs` - The variable costs","ref":"FinancialFormulas.html#contribution_margin/2-required"},{"type":"function","title":"Examples - FinancialFormulas.contribution_margin/2","doc":"iex> FinancialFormulas.contribution_margin(1000, 500)\n500","ref":"FinancialFormulas.html#contribution_margin/2-examples"},{"type":"function","title":"FinancialFormulas.contribution_margin_per_unit/2","doc":"Calculates the contribution margin per unit","ref":"FinancialFormulas.html#contribution_margin_per_unit/2"},{"type":"function","title":"Formula - FinancialFormulas.contribution_margin_per_unit/2","doc":"price_per_unit - variable_cost_per_unit","ref":"FinancialFormulas.html#contribution_margin_per_unit/2-formula"},{"type":"function","title":"Required - FinancialFormulas.contribution_margin_per_unit/2","doc":"* `price_per_unit` - The price per unit\n* `variable_cost_per_unit` - The variable cost per unit","ref":"FinancialFormulas.html#contribution_margin_per_unit/2-required"},{"type":"function","title":"Examples - FinancialFormulas.contribution_margin_per_unit/2","doc":"iex> FinancialFormulas.contribution_margin_per_unit(10, 5)\n5","ref":"FinancialFormulas.html#contribution_margin_per_unit/2-examples"},{"type":"function","title":"FinancialFormulas.contribution_margin_ratio/2","doc":"Calculates the contribution margin ratio","ref":"FinancialFormulas.html#contribution_margin_ratio/2"},{"type":"function","title":"Formula - FinancialFormulas.contribution_margin_ratio/2","doc":"contribution_margin / total_sales_revenue","ref":"FinancialFormulas.html#contribution_margin_ratio/2-formula"},{"type":"function","title":"Required - FinancialFormulas.contribution_margin_ratio/2","doc":"* `contribution_margin` - The contribution margin\n* `total_sales_revenue` - The total sales revenue","ref":"FinancialFormulas.html#contribution_margin_ratio/2-required"},{"type":"function","title":"Examples - FinancialFormulas.contribution_margin_ratio/2","doc":"iex> FinancialFormulas.contribution_margin_ratio(500, 1000)\n0.5","ref":"FinancialFormulas.html#contribution_margin_ratio/2-examples"},{"type":"function","title":"FinancialFormulas.cost_of_goods_sold/3","doc":"Calculates the costs of goods sold of an entity.","ref":"FinancialFormulas.html#cost_of_goods_sold/3"},{"type":"function","title":"Formula - FinancialFormulas.cost_of_goods_sold/3","doc":"beginning_inventory + purchases - ending_inventory","ref":"FinancialFormulas.html#cost_of_goods_sold/3-formula"},{"type":"function","title":"Required - FinancialFormulas.cost_of_goods_sold/3","doc":"* `beginning_inventory` - The beginning inventory.\n* `purchases` - The purchases.\n* `ending_inventory` - The ending inventory.","ref":"FinancialFormulas.html#cost_of_goods_sold/3-required"},{"type":"function","title":"Examples - FinancialFormulas.cost_of_goods_sold/3","doc":"iex> FinancialFormulas.cost_of_goods_sold(100, 200, 50)\n250","ref":"FinancialFormulas.html#cost_of_goods_sold/3-examples"},{"type":"function","title":"FinancialFormulas.cost_to_income_ratio/2","doc":"Calculates the cost to income ratio of an entity.","ref":"FinancialFormulas.html#cost_to_income_ratio/2"},{"type":"function","title":"Formula - FinancialFormulas.cost_to_income_ratio/2","doc":"operational_costs / operational_income","ref":"FinancialFormulas.html#cost_to_income_ratio/2-formula"},{"type":"function","title":"Required - FinancialFormulas.cost_to_income_ratio/2","doc":"* `operational_costs` - The operational costs of the entity.\n* `operational_income` - The operational income of the entity.","ref":"FinancialFormulas.html#cost_to_income_ratio/2-required"},{"type":"function","title":"Examples - FinancialFormulas.cost_to_income_ratio/2","doc":"iex> FinancialFormulas.cost_to_income_ratio(100, 200)\n0.5","ref":"FinancialFormulas.html#cost_to_income_ratio/2-examples"},{"type":"function","title":"FinancialFormulas.current_ratio/2","doc":"Calculates the current ratio of an entity.","ref":"FinancialFormulas.html#current_ratio/2"},{"type":"function","title":"Formula - FinancialFormulas.current_ratio/2","doc":"current_assets / current_liabilities","ref":"FinancialFormulas.html#current_ratio/2-formula"},{"type":"function","title":"Required - FinancialFormulas.current_ratio/2","doc":"* `current_assets` - The current assets of the entity.\n* `current_liabilities` - The current liabilities of the entity.","ref":"FinancialFormulas.html#current_ratio/2-required"},{"type":"function","title":"Examples - FinancialFormulas.current_ratio/2","doc":"iex> FinancialFormulas.current_ratio(100, 200)\n0.5","ref":"FinancialFormulas.html#current_ratio/2-examples"},{"type":"function","title":"FinancialFormulas.current_yield/2","doc":"Calculates the current yield of a bond.","ref":"FinancialFormulas.html#current_yield/2"},{"type":"function","title":"Formula - FinancialFormulas.current_yield/2","doc":"annual_income / current_price","ref":"FinancialFormulas.html#current_yield/2-formula"},{"type":"function","title":"Required - FinancialFormulas.current_yield/2","doc":"* `annual_coupons` - The annual coupons of the bond.\n* `current_price` - The current price of the bond.","ref":"FinancialFormulas.html#current_yield/2-required"},{"type":"function","title":"Examples - FinancialFormulas.current_yield/2","doc":"iex> FinancialFormulas.current_yield(100, 200)\n0.5","ref":"FinancialFormulas.html#current_yield/2-examples"},{"type":"function","title":"FinancialFormulas.days_in_inventory/1","doc":"Calculates the inventory turnover of an entity.","ref":"FinancialFormulas.html#days_in_inventory/1"},{"type":"function","title":"Formula - FinancialFormulas.days_in_inventory/1","doc":"365 / inventory_turnover","ref":"FinancialFormulas.html#days_in_inventory/1-formula"},{"type":"function","title":"Required - FinancialFormulas.days_in_inventory/1","doc":"* `inventory_turnover` - The inventory turnover of the entity.","ref":"FinancialFormulas.html#days_in_inventory/1-required"},{"type":"function","title":"Examples - FinancialFormulas.days_in_inventory/1","doc":"iex> FinancialFormulas.days_in_inventory(10)\n36.5","ref":"FinancialFormulas.html#days_in_inventory/1-examples"},{"type":"function","title":"FinancialFormulas.days_payable_outstanding/2","doc":"Calculates the days payable outstanding of an entity.","ref":"FinancialFormulas.html#days_payable_outstanding/2"},{"type":"function","title":"Formula - FinancialFormulas.days_payable_outstanding/2","doc":"accounts_payable / cost_of_goods_sold * 365","ref":"FinancialFormulas.html#days_payable_outstanding/2-formula"},{"type":"function","title":"Required - FinancialFormulas.days_payable_outstanding/2","doc":"* `accounts_payable` - The accounts payable of the entity.\n* `cost_of_goods_sold` - The cost of goods sold of the entity.","ref":"FinancialFormulas.html#days_payable_outstanding/2-required"},{"type":"function","title":"Examples - FinancialFormulas.days_payable_outstanding/2","doc":"iex> FinancialFormulas.days_payable_outstanding(100, 200)\n182.5","ref":"FinancialFormulas.html#days_payable_outstanding/2-examples"},{"type":"function","title":"FinancialFormulas.days_sales_of_inventory/2","doc":"Calculates the days sales of inventory of an entity.","ref":"FinancialFormulas.html#days_sales_of_inventory/2"},{"type":"function","title":"Formula - FinancialFormulas.days_sales_of_inventory/2","doc":"average_inventory / cost_of_goods_sold * 365","ref":"FinancialFormulas.html#days_sales_of_inventory/2-formula"},{"type":"function","title":"Required - FinancialFormulas.days_sales_of_inventory/2","doc":"* `average_inventory` - The average inventory of the entity.\n* `cost_of_goods_sold` - The cost of goods sold of the entity.","ref":"FinancialFormulas.html#days_sales_of_inventory/2-required"},{"type":"function","title":"Examples - FinancialFormulas.days_sales_of_inventory/2","doc":"iex> FinancialFormulas.days_sales_of_inventory(100, 200)\n182.5","ref":"FinancialFormulas.html#days_sales_of_inventory/2-examples"},{"type":"function","title":"FinancialFormulas.days_sales_outstanding/2","doc":"Calculates the days sales outstanding of an entity.","ref":"FinancialFormulas.html#days_sales_outstanding/2"},{"type":"function","title":"Formula - FinancialFormulas.days_sales_outstanding/2","doc":"accounts_receivable / total_credit_sales * 365","ref":"FinancialFormulas.html#days_sales_outstanding/2-formula"},{"type":"function","title":"Required - FinancialFormulas.days_sales_outstanding/2","doc":"* `accounts_receivable` - The accounts receivable of the entity.\n* `total_credit_sales` - The total credit sales of the entity.","ref":"FinancialFormulas.html#days_sales_outstanding/2-required"},{"type":"function","title":"Examples - FinancialFormulas.days_sales_outstanding/2","doc":"iex> FinancialFormulas.days_sales_outstanding(100, 200)\n182.5","ref":"FinancialFormulas.html#days_sales_outstanding/2-examples"},{"type":"function","title":"FinancialFormulas.debt_coverage_ratio/2","doc":"Calculates the debt coverage ratio of an entity.","ref":"FinancialFormulas.html#debt_coverage_ratio/2"},{"type":"function","title":"Formula - FinancialFormulas.debt_coverage_ratio/2","doc":"net_operating_income / total_debt_service","ref":"FinancialFormulas.html#debt_coverage_ratio/2-formula"},{"type":"function","title":"Required - FinancialFormulas.debt_coverage_ratio/2","doc":"* `net_operating_income` - The net operating income of the entity.\n* `total_debt_service` - The total debt service of the entity.","ref":"FinancialFormulas.html#debt_coverage_ratio/2-required"},{"type":"function","title":"Examples - FinancialFormulas.debt_coverage_ratio/2","doc":"iex> FinancialFormulas.debt_coverage_ratio(100, 200)\n0.5","ref":"FinancialFormulas.html#debt_coverage_ratio/2-examples"},{"type":"function","title":"FinancialFormulas.debt_ratio/2","doc":"Calculates the debt ratio of an entity.","ref":"FinancialFormulas.html#debt_ratio/2"},{"type":"function","title":"Formula - FinancialFormulas.debt_ratio/2","doc":"total_liabilities / total_assets","ref":"FinancialFormulas.html#debt_ratio/2-formula"},{"type":"function","title":"Required - FinancialFormulas.debt_ratio/2","doc":"* `total_liabilities` - The total liabilities of the entity.\n* `total_assets` - The total assets of the entity.","ref":"FinancialFormulas.html#debt_ratio/2-required"},{"type":"function","title":"Examples - FinancialFormulas.debt_ratio/2","doc":"iex> FinancialFormulas.debt_ratio(100, 200)\n0.5","ref":"FinancialFormulas.html#debt_ratio/2-examples"},{"type":"function","title":"FinancialFormulas.debt_to_equity_ratio/2","doc":"Calculates the debt to equity ratio of an entity.","ref":"FinancialFormulas.html#debt_to_equity_ratio/2"},{"type":"function","title":"Formula - FinancialFormulas.debt_to_equity_ratio/2","doc":"total_liabilities / total_equity","ref":"FinancialFormulas.html#debt_to_equity_ratio/2-formula"},{"type":"function","title":"Required - FinancialFormulas.debt_to_equity_ratio/2","doc":"* `total_liabilities` - The total liabilities of the entity.\n* `total_equity` - The total equity of the entity.","ref":"FinancialFormulas.html#debt_to_equity_ratio/2-required"},{"type":"function","title":"Examples - FinancialFormulas.debt_to_equity_ratio/2","doc":"iex> FinancialFormulas.debt_to_equity_ratio(100, 200)\n0.5","ref":"FinancialFormulas.html#debt_to_equity_ratio/2-examples"},{"type":"function","title":"FinancialFormulas.debt_to_income_ratio/2","doc":"Calculates the debt to income ratio of an entity.","ref":"FinancialFormulas.html#debt_to_income_ratio/2"},{"type":"function","title":"Formula - FinancialFormulas.debt_to_income_ratio/2","doc":"debt / income","ref":"FinancialFormulas.html#debt_to_income_ratio/2-formula"},{"type":"function","title":"Required - FinancialFormulas.debt_to_income_ratio/2","doc":"* `debt` - The total debt of the entity.\n* `income` - The total income of the entity.","ref":"FinancialFormulas.html#debt_to_income_ratio/2-required"},{"type":"function","title":"Examples - FinancialFormulas.debt_to_income_ratio/2","doc":"iex> FinancialFormulas.debt_to_income_ratio(100, 200)\n0.5","ref":"FinancialFormulas.html#debt_to_income_ratio/2-examples"},{"type":"function","title":"FinancialFormulas.diluted_earnings_per_share/3","doc":"Calculates the diluted earnings per share of an entity.","ref":"FinancialFormulas.html#diluted_earnings_per_share/3"},{"type":"function","title":"Formula - FinancialFormulas.diluted_earnings_per_share/3","doc":"net_income / (average_shares + other_convertible_instruments)","ref":"FinancialFormulas.html#diluted_earnings_per_share/3-formula"},{"type":"function","title":"Required - FinancialFormulas.diluted_earnings_per_share/3","doc":"* `net_income` - The net income of the entity.\n* `average_shares` - The average shares of the entity.\n* `other_convertible_instruments` - The other convertible instruments of the entity.","ref":"FinancialFormulas.html#diluted_earnings_per_share/3-required"},{"type":"function","title":"Examples - FinancialFormulas.diluted_earnings_per_share/3","doc":"iex> FinancialFormulas.diluted_earnings_per_share(100, 200, 300)\n0.2\n\niex> FinancialFormulas.diluted_earnings_per_share(100, 200)\n0.5","ref":"FinancialFormulas.html#diluted_earnings_per_share/3-examples"},{"type":"function","title":"FinancialFormulas.dividend_payout_ratio/2","doc":"Calculates the dividend payout ratio of an entity.","ref":"FinancialFormulas.html#dividend_payout_ratio/2"},{"type":"function","title":"Formula - FinancialFormulas.dividend_payout_ratio/2","doc":"dividends / net_income","ref":"FinancialFormulas.html#dividend_payout_ratio/2-formula"},{"type":"function","title":"Required - FinancialFormulas.dividend_payout_ratio/2","doc":"* `dividends` - The dividends of the entity.\n* `net_income` - The net income of the entity.","ref":"FinancialFormulas.html#dividend_payout_ratio/2-required"},{"type":"function","title":"Examples - FinancialFormulas.dividend_payout_ratio/2","doc":"iex> FinancialFormulas.dividend_payout_ratio(100, 200)\n0.5","ref":"FinancialFormulas.html#dividend_payout_ratio/2-examples"},{"type":"function","title":"FinancialFormulas.dividend_yield/2","doc":"Calculates the dividend yield of an entity.","ref":"FinancialFormulas.html#dividend_yield/2"},{"type":"function","title":"Formula - FinancialFormulas.dividend_yield/2","doc":"dividends / current_price","ref":"FinancialFormulas.html#dividend_yield/2-formula"},{"type":"function","title":"Required - FinancialFormulas.dividend_yield/2","doc":"* `dividends` - The dividends of the entity.\n* `current_price` - The current price of the entity.","ref":"FinancialFormulas.html#dividend_yield/2-required"},{"type":"function","title":"Examples - FinancialFormulas.dividend_yield/2","doc":"iex> FinancialFormulas.dividend_yield(100, 200)\n0.5","ref":"FinancialFormulas.html#dividend_yield/2-examples"},{"type":"function","title":"FinancialFormulas.dividends_per_share/2","doc":"Calculates the divdends per share of an entity.","ref":"FinancialFormulas.html#dividends_per_share/2"},{"type":"function","title":"Formula - FinancialFormulas.dividends_per_share/2","doc":"dividends / shares","ref":"FinancialFormulas.html#dividends_per_share/2-formula"},{"type":"function","title":"Required - FinancialFormulas.dividends_per_share/2","doc":"* `dividends` - The dividends of the entity.\n* `shares` - The shares of the entity.","ref":"FinancialFormulas.html#dividends_per_share/2-required"},{"type":"function","title":"Examples - FinancialFormulas.dividends_per_share/2","doc":"iex> FinancialFormulas.dividends_per_share(100, 200)\n0.5","ref":"FinancialFormulas.html#dividends_per_share/2-examples"},{"type":"function","title":"FinancialFormulas.doubling_time/1","doc":"Calculates the doubling time of an investment.","ref":"FinancialFormulas.html#doubling_time/1"},{"type":"function","title":"Formula - FinancialFormulas.doubling_time/1","doc":"log(2) / log(1 + rate_of_returns)","ref":"FinancialFormulas.html#doubling_time/1-formula"},{"type":"function","title":"Required - FinancialFormulas.doubling_time/1","doc":"* `rate_of_returns` - The rate of returns of the investment.","ref":"FinancialFormulas.html#doubling_time/1-required"},{"type":"function","title":"Examples - FinancialFormulas.doubling_time/1","doc":"iex> FinancialFormulas.doubling_time(0.1)\n7.272540897341713","ref":"FinancialFormulas.html#doubling_time/1-examples"},{"type":"function","title":"FinancialFormulas.doubling_time_continuous_compounding/1","doc":"Calculates the doubling time of an investment with continuous compounding.","ref":"FinancialFormulas.html#doubling_time_continuous_compounding/1"},{"type":"function","title":"Formula - FinancialFormulas.doubling_time_continuous_compounding/1","doc":"log(2) / rate_of_returns","ref":"FinancialFormulas.html#doubling_time_continuous_compounding/1-formula"},{"type":"function","title":"Required - FinancialFormulas.doubling_time_continuous_compounding/1","doc":"* `rate_of_returns` - The rate of returns of the investment.","ref":"FinancialFormulas.html#doubling_time_continuous_compounding/1-required"},{"type":"function","title":"Examples - FinancialFormulas.doubling_time_continuous_compounding/1","doc":"iex> FinancialFormulas.doubling_time_continuous_compounding(0.1)\n6.931471805599452","ref":"FinancialFormulas.html#doubling_time_continuous_compounding/1-examples"},{"type":"function","title":"FinancialFormulas.doubling_time_simple/1","doc":"Calculates the doubling time of an investment with simple interest.","ref":"FinancialFormulas.html#doubling_time_simple/1"},{"type":"function","title":"Formula - FinancialFormulas.doubling_time_simple/1","doc":"1 / rate_of_returns","ref":"FinancialFormulas.html#doubling_time_simple/1-formula"},{"type":"function","title":"Required - FinancialFormulas.doubling_time_simple/1","doc":"* `rate_of_returns` - The rate of returns of the investment.","ref":"FinancialFormulas.html#doubling_time_simple/1-required"},{"type":"function","title":"Examples - FinancialFormulas.doubling_time_simple/1","doc":"iex> FinancialFormulas.doubling_time_simple(0.1)\n10.0","ref":"FinancialFormulas.html#doubling_time_simple/1-examples"},{"type":"function","title":"FinancialFormulas.earnings_per_share/2","doc":"Calculates the earnings per share of an entity.","ref":"FinancialFormulas.html#earnings_per_share/2"},{"type":"function","title":"Formula - FinancialFormulas.earnings_per_share/2","doc":"net_income / average_shares","ref":"FinancialFormulas.html#earnings_per_share/2-formula"},{"type":"function","title":"Required - FinancialFormulas.earnings_per_share/2","doc":"* `net_income` - The net income of the entity.\n* `average_shares` - The average shares of the entity.","ref":"FinancialFormulas.html#earnings_per_share/2-required"},{"type":"function","title":"Examples - FinancialFormulas.earnings_per_share/2","doc":"iex> FinancialFormulas.earnings_per_share(100, 200)\n0.5","ref":"FinancialFormulas.html#earnings_per_share/2-examples"},{"type":"function","title":"FinancialFormulas.ebit/3","doc":"Calculates the ebit of an entity.","ref":"FinancialFormulas.html#ebit/3"},{"type":"function","title":"Formula - FinancialFormulas.ebit/3","doc":"sales_revenue - cost_of_goods_sold - operating_expenses","ref":"FinancialFormulas.html#ebit/3-formula"},{"type":"function","title":"Required - FinancialFormulas.ebit/3","doc":"* `sales_revenue` - The sales/revenue of the entity.\n* `cost_of_goods_sold` - The cost of goods sold of the entity.\n* `operating_expenses` - The operating expenses of the entity.","ref":"FinancialFormulas.html#ebit/3-required"},{"type":"function","title":"Examples - FinancialFormulas.ebit/3","doc":"iex> FinancialFormulas.ebit(100, 200, 300)\n-400","ref":"FinancialFormulas.html#ebit/3-examples"},{"type":"function","title":"FinancialFormulas.ebitda/4","doc":"Calculates the ebitda of an entity.","ref":"FinancialFormulas.html#ebitda/4"},{"type":"function","title":"Formula - FinancialFormulas.ebitda/4","doc":"sales_revenue - cost_of_goods_sold - operating_expenses - depreciation_and_amortization","ref":"FinancialFormulas.html#ebitda/4-formula"},{"type":"function","title":"Required - FinancialFormulas.ebitda/4","doc":"* `sales_revenue` - The sales/revenue of the entity.\n* `cost_of_goods_sold` - The cost of goods sold of the entity.\n* `operating_expenses` - The operating expenses of the entity.\n* `depreciation_and_amortization` - The depreciation and amortization of the entity.","ref":"FinancialFormulas.html#ebitda/4-required"},{"type":"function","title":"Examples - FinancialFormulas.ebitda/4","doc":"iex> FinancialFormulas.ebitda(100, 200, 300, 400)\n-800","ref":"FinancialFormulas.html#ebitda/4-examples"},{"type":"function","title":"FinancialFormulas.equity_multiplier/2","doc":"Calculates the equity multiplier of an entity.","ref":"FinancialFormulas.html#equity_multiplier/2"},{"type":"function","title":"Formula - FinancialFormulas.equity_multiplier/2","doc":"total_assets / total_equity","ref":"FinancialFormulas.html#equity_multiplier/2-formula"},{"type":"function","title":"Required - FinancialFormulas.equity_multiplier/2","doc":"* `total_assets` - The total assets of the entity.\n* `total_equity` - The total equity of the entity.","ref":"FinancialFormulas.html#equity_multiplier/2-required"},{"type":"function","title":"Examples - FinancialFormulas.equity_multiplier/2","doc":"iex> FinancialFormulas.equity_multiplier(100, 200)\n0.5","ref":"FinancialFormulas.html#equity_multiplier/2-examples"},{"type":"function","title":"FinancialFormulas.estimated_earnings/2","doc":"Calculates the estimated earnings of an entity.","ref":"FinancialFormulas.html#estimated_earnings/2"},{"type":"function","title":"Formula - FinancialFormulas.estimated_earnings/2","doc":"forcasted_sales - forcasted_expenses","ref":"FinancialFormulas.html#estimated_earnings/2-formula"},{"type":"function","title":"Required - FinancialFormulas.estimated_earnings/2","doc":"* `forcasted_sales` - The forcasted sales of the entity.\n* `forcasted_expenses` - The forcasted expenses of the entity.","ref":"FinancialFormulas.html#estimated_earnings/2-required"},{"type":"function","title":"Examples - FinancialFormulas.estimated_earnings/2","doc":"iex> FinancialFormulas.estimated_earnings(100, 200)\n-100","ref":"FinancialFormulas.html#estimated_earnings/2-examples"},{"type":"function","title":"FinancialFormulas.free_cash_flow_to_equity/5","doc":"Calculates the free cash flow to equity of an entity.","ref":"FinancialFormulas.html#free_cash_flow_to_equity/5"},{"type":"function","title":"Formula - FinancialFormulas.free_cash_flow_to_equity/5","doc":"net_income + depreciation_and_amortization - capital_expenditures - change_in_working_capital + net_borrowing","ref":"FinancialFormulas.html#free_cash_flow_to_equity/5-formula"},{"type":"function","title":"Required - FinancialFormulas.free_cash_flow_to_equity/5","doc":"* `net_income` - The net income of the entity.\n* `depreciation_and_amortization` - The depreciation and amortization of the entity.\n* `capital_expenditures` - The capital expenditures of the entity.\n* `change_in_working_capital` - The change in working capital of the entity.\n* `net_borrowing` - The net borrowing of the entity.","ref":"FinancialFormulas.html#free_cash_flow_to_equity/5-required"},{"type":"function","title":"Examples - FinancialFormulas.free_cash_flow_to_equity/5","doc":"iex> FinancialFormulas.free_cash_flow_to_equity(100, 200, 300, 400, 500)\n100","ref":"FinancialFormulas.html#free_cash_flow_to_equity/5-examples"},{"type":"function","title":"FinancialFormulas.free_cash_flow_to_firm/5","doc":"Calculates the free cash flow to firm of an entity.","ref":"FinancialFormulas.html#free_cash_flow_to_firm/5"},{"type":"function","title":"Formula - FinancialFormulas.free_cash_flow_to_firm/5","doc":"ebit * (1 - tax_rate) + depreciation_and_amortization - capital_expenditures - change_in_working_capital","ref":"FinancialFormulas.html#free_cash_flow_to_firm/5-formula"},{"type":"function","title":"Required - FinancialFormulas.free_cash_flow_to_firm/5","doc":"* `ebit` - The earnings before interest and taxes of the entity.\n* `tax_rate` - The tax rate of the entity.\n* `depreciation_and_amortization` - The depreciation and amortization of the entity.\n* `capital_expenditures` - The capital expenditures of the entity.\n* `change_in_working_capital` - The change in working capital of the entity.","ref":"FinancialFormulas.html#free_cash_flow_to_firm/5-required"},{"type":"function","title":"Examples - FinancialFormulas.free_cash_flow_to_firm/5","doc":"iex> FinancialFormulas.free_cash_flow_to_firm(100, 200, 300, 400, 500)\n-20500","ref":"FinancialFormulas.html#free_cash_flow_to_firm/5-examples"},{"type":"function","title":"FinancialFormulas.future_value/3","doc":"Calculates the future value of an investment.","ref":"FinancialFormulas.html#future_value/3"},{"type":"function","title":"Formula - FinancialFormulas.future_value/3","doc":"initial_cash_flow * (1 + rate_of_returns) ^ number_of_periods","ref":"FinancialFormulas.html#future_value/3-formula"},{"type":"function","title":"Required - FinancialFormulas.future_value/3","doc":"* `initial_cash_flow` - The initial cash flow of the investment.\n* `rate_of_returns` - The rate of returns of the investment.\n* `number_of_periods` - The number of periods.","ref":"FinancialFormulas.html#future_value/3-required"},{"type":"function","title":"Examples - FinancialFormulas.future_value/3","doc":"iex> FinancialFormulas.future_value(100, 0.1, 2)\n121.00000000000001","ref":"FinancialFormulas.html#future_value/3-examples"},{"type":"function","title":"FinancialFormulas.future_value_continuous_compounding/3","doc":"Calculates the future value of an investment with continuous compounding.","ref":"FinancialFormulas.html#future_value_continuous_compounding/3"},{"type":"function","title":"Formula - FinancialFormulas.future_value_continuous_compounding/3","doc":"present_value * e ^ (rate_of_returns * number_of_periods)","ref":"FinancialFormulas.html#future_value_continuous_compounding/3-formula"},{"type":"function","title":"Required - FinancialFormulas.future_value_continuous_compounding/3","doc":"* `present_value` - The present value of the investment.\n* `rate_of_returns` - The rate of returns of the investment.\n* `number_of_periods` - The number of periods.","ref":"FinancialFormulas.html#future_value_continuous_compounding/3-required"},{"type":"function","title":"Examples - FinancialFormulas.future_value_continuous_compounding/3","doc":"iex> FinancialFormulas.future_value_continuous_compounding(100, 0.1, 2)\n122.14027581601698","ref":"FinancialFormulas.html#future_value_continuous_compounding/3-examples"},{"type":"function","title":"FinancialFormulas.future_value_of_annuity/3","doc":"Calculates the future value of an annuity.","ref":"FinancialFormulas.html#future_value_of_annuity/3"},{"type":"function","title":"Formula - FinancialFormulas.future_value_of_annuity/3","doc":"payment * ((1 + interest_rate) ^ number_of_payments - 1) / interest_rate","ref":"FinancialFormulas.html#future_value_of_annuity/3-formula"},{"type":"function","title":"Required - FinancialFormulas.future_value_of_annuity/3","doc":"* `payment` - The amount of each payment.\n* `interest_rate` - The interest rate of the investment.\n* `number_of_payments` - The number of payments.","ref":"FinancialFormulas.html#future_value_of_annuity/3-required"},{"type":"function","title":"Examples - FinancialFormulas.future_value_of_annuity/3","doc":"iex> FinancialFormulas.future_value_of_annuity(100, 0.1, 2)\n210.0000000000002","ref":"FinancialFormulas.html#future_value_of_annuity/3-examples"},{"type":"function","title":"FinancialFormulas.geometric_mean/1","doc":"Calculates the geometric mean of a set of returns.","ref":"FinancialFormulas.html#geometric_mean/1"},{"type":"function","title":"Formula - FinancialFormulas.geometric_mean/1","doc":"(1 + rate_of_returns) ^ (1 / n) - 1","ref":"FinancialFormulas.html#geometric_mean/1-formula"},{"type":"function","title":"Required - FinancialFormulas.geometric_mean/1","doc":"* `rate_of_returns` - The rate of returns of the investment.","ref":"FinancialFormulas.html#geometric_mean/1-required"},{"type":"function","title":"Examples - FinancialFormulas.geometric_mean/1","doc":"iex> FinancialFormulas.geometric_mean([0.1, 0.2, 0.3])\n0.1972157672583763","ref":"FinancialFormulas.html#geometric_mean/1-examples"},{"type":"function","title":"FinancialFormulas.gross_profit_margin/2","doc":"Calculates the gross profit margin of an entity.","ref":"FinancialFormulas.html#gross_profit_margin/2"},{"type":"function","title":"Formula - FinancialFormulas.gross_profit_margin/2","doc":"(sales_revenue - cost_of_goods_sold) / sales_revenue","ref":"FinancialFormulas.html#gross_profit_margin/2-formula"},{"type":"function","title":"Required - FinancialFormulas.gross_profit_margin/2","doc":"* `sales_revenue` - The sales/revenue of the entity.\n* `cost_of_goods_sold` - The cost of goods sold of the entity.","ref":"FinancialFormulas.html#gross_profit_margin/2-required"},{"type":"function","title":"Examples - FinancialFormulas.gross_profit_margin/2","doc":"iex> FinancialFormulas.gross_profit_margin(100, 200)\n-1.0","ref":"FinancialFormulas.html#gross_profit_margin/2-examples"},{"type":"function","title":"FinancialFormulas.interest_coverage_ratio/2","doc":"Calculates the interest coverage ratio of an entity.","ref":"FinancialFormulas.html#interest_coverage_ratio/2"},{"type":"function","title":"Formula - FinancialFormulas.interest_coverage_ratio/2","doc":"ebit / interest_expense","ref":"FinancialFormulas.html#interest_coverage_ratio/2-formula"},{"type":"function","title":"Required - FinancialFormulas.interest_coverage_ratio/2","doc":"* `ebit` - The earnings before interest and taxes of the entity.\n* `interest_expense` - The interest expense of the entity.","ref":"FinancialFormulas.html#interest_coverage_ratio/2-required"},{"type":"function","title":"Examples - FinancialFormulas.interest_coverage_ratio/2","doc":"iex> FinancialFormulas.interest_coverage_ratio(100, 200)\n0.5","ref":"FinancialFormulas.html#interest_coverage_ratio/2-examples"},{"type":"function","title":"FinancialFormulas.inventory_turnover_ratio/2","doc":"Calculates the inventory turnover ratio of an entity.","ref":"FinancialFormulas.html#inventory_turnover_ratio/2"},{"type":"function","title":"Formula - FinancialFormulas.inventory_turnover_ratio/2","doc":"cost_of_goods_sold / average_inventory","ref":"FinancialFormulas.html#inventory_turnover_ratio/2-formula"},{"type":"function","title":"Required - FinancialFormulas.inventory_turnover_ratio/2","doc":"* `cost_of_goods_sold` - The cost of goods sold of the entity.\n* `average_inventory` - The average inventory of the entity.","ref":"FinancialFormulas.html#inventory_turnover_ratio/2-required"},{"type":"function","title":"Examples - FinancialFormulas.inventory_turnover_ratio/2","doc":"iex> FinancialFormulas.inventory_turnover_ratio(100, 200)\n0.5","ref":"FinancialFormulas.html#inventory_turnover_ratio/2-examples"},{"type":"function","title":"FinancialFormulas.loan_to_deposit_ratio/2","doc":"Calculates the loan to deposit ratio of an entity.","ref":"FinancialFormulas.html#loan_to_deposit_ratio/2"},{"type":"function","title":"Formula - FinancialFormulas.loan_to_deposit_ratio/2","doc":"total_loans / total_deposits","ref":"FinancialFormulas.html#loan_to_deposit_ratio/2-formula"},{"type":"function","title":"Required - FinancialFormulas.loan_to_deposit_ratio/2","doc":"* `total_loans` - The total loans of the entity.\n* `total_deposits` - The total deposits of the entity.","ref":"FinancialFormulas.html#loan_to_deposit_ratio/2-required"},{"type":"function","title":"Examples - FinancialFormulas.loan_to_deposit_ratio/2","doc":"iex> FinancialFormulas.loan_to_deposit_ratio(100, 200)\n0.5","ref":"FinancialFormulas.html#loan_to_deposit_ratio/2-examples"},{"type":"function","title":"FinancialFormulas.margin_of_safty/2","doc":"Calculates the margin of safety of an investment.","ref":"FinancialFormulas.html#margin_of_safty/2"},{"type":"function","title":"Formula - FinancialFormulas.margin_of_safty/2","doc":"(intrinsic_value - current_price) / intrinsic_value","ref":"FinancialFormulas.html#margin_of_safty/2-formula"},{"type":"function","title":"Required - FinancialFormulas.margin_of_safty/2","doc":"* `current_price` - The current price of the investment.\n* `intrinsic_value` - The intrinsic value of the investment.","ref":"FinancialFormulas.html#margin_of_safty/2-required"},{"type":"function","title":"Examples - FinancialFormulas.margin_of_safty/2","doc":"iex> FinancialFormulas.margin_of_safty(100, 200)\n0.5","ref":"FinancialFormulas.html#margin_of_safty/2-examples"},{"type":"function","title":"FinancialFormulas.market_capitalization/2","doc":"Calculates the market capitalization of an entity.","ref":"FinancialFormulas.html#market_capitalization/2"},{"type":"function","title":"Formula - FinancialFormulas.market_capitalization/2","doc":"price_per_share * outstanding_shares","ref":"FinancialFormulas.html#market_capitalization/2-formula"},{"type":"function","title":"Required - FinancialFormulas.market_capitalization/2","doc":"* `price_per_share` - The price per share of the entity.\n* `outstanding_shares` - The outstanding shares of the entity.","ref":"FinancialFormulas.html#market_capitalization/2-required"},{"type":"function","title":"Examples - FinancialFormulas.market_capitalization/2","doc":"iex> FinancialFormulas.market_capitalization(100, 200)\n20000","ref":"FinancialFormulas.html#market_capitalization/2-examples"},{"type":"function","title":"FinancialFormulas.market_to_book_ratio/2","doc":"Calculates the market to book ratio of an entity.","ref":"FinancialFormulas.html#market_to_book_ratio/2"},{"type":"function","title":"Formula - FinancialFormulas.market_to_book_ratio/2","doc":"market_price_per_share / book_value_per_share","ref":"FinancialFormulas.html#market_to_book_ratio/2-formula"},{"type":"function","title":"Required - FinancialFormulas.market_to_book_ratio/2","doc":"* `market_price_per_share` - The market price per share of the entity.\n* `book_value_per_share` - The book value per share of the entity.","ref":"FinancialFormulas.html#market_to_book_ratio/2-required"},{"type":"function","title":"Examples - FinancialFormulas.market_to_book_ratio/2","doc":"iex> FinancialFormulas.market_to_book_ratio(100, 200)\n0.5","ref":"FinancialFormulas.html#market_to_book_ratio/2-examples"},{"type":"function","title":"FinancialFormulas.net_asset_value/3","doc":"Calculates the net asset value of an entity.","ref":"FinancialFormulas.html#net_asset_value/3"},{"type":"function","title":"Formula - FinancialFormulas.net_asset_value/3","doc":"(assets - liabilities) / shares","ref":"FinancialFormulas.html#net_asset_value/3-formula"},{"type":"function","title":"Required - FinancialFormulas.net_asset_value/3","doc":"* `assets` - The assets of the entity.\n* `liabilities` - The liabilities of the entity.\n* `shares` - The shares of the entity.","ref":"FinancialFormulas.html#net_asset_value/3-required"},{"type":"function","title":"Examples - FinancialFormulas.net_asset_value/3","doc":"iex> FinancialFormulas.net_asset_value(100, 200, 300)\n-0.3333333333333333","ref":"FinancialFormulas.html#net_asset_value/3-examples"},{"type":"function","title":"FinancialFormulas.net_intrest_income/2","doc":"Calculates the net intrest income of an entity.","ref":"FinancialFormulas.html#net_intrest_income/2"},{"type":"function","title":"Formula - FinancialFormulas.net_intrest_income/2","doc":"intrest_income - intrest_expense","ref":"FinancialFormulas.html#net_intrest_income/2-formula"},{"type":"function","title":"Required - FinancialFormulas.net_intrest_income/2","doc":"* `intrest_income` - The intrest income of the entity.\n* `intrest_expense` - The intrest expense of the entity.","ref":"FinancialFormulas.html#net_intrest_income/2-required"},{"type":"function","title":"Examples - FinancialFormulas.net_intrest_income/2","doc":"iex> FinancialFormulas.net_intrest_income(100, 200)\n-100","ref":"FinancialFormulas.html#net_intrest_income/2-examples"},{"type":"function","title":"FinancialFormulas.net_intrest_margin/2","doc":"Calculates the net intrest margin of an entity.","ref":"FinancialFormulas.html#net_intrest_margin/2"},{"type":"function","title":"Formula - FinancialFormulas.net_intrest_margin/2","doc":"net_intrest_income / average_earning_assets","ref":"FinancialFormulas.html#net_intrest_margin/2-formula"},{"type":"function","title":"Required - FinancialFormulas.net_intrest_margin/2","doc":"* `net_intrest_income` - The net intrest income of the entity.\n* `average_earning_assets` - The average earning assets of the entity.","ref":"FinancialFormulas.html#net_intrest_margin/2-required"},{"type":"function","title":"Examples - FinancialFormulas.net_intrest_margin/2","doc":"iex> FinancialFormulas.net_intrest_margin(100, 200)\n0.5","ref":"FinancialFormulas.html#net_intrest_margin/2-examples"},{"type":"function","title":"FinancialFormulas.net_intrest_spread/2","doc":"Calculates the net intrest spread of an entity.","ref":"FinancialFormulas.html#net_intrest_spread/2"},{"type":"function","title":"Formula - FinancialFormulas.net_intrest_spread/2","doc":"intrest_income_rate - intrest_expense_rate","ref":"FinancialFormulas.html#net_intrest_spread/2-formula"},{"type":"function","title":"Required - FinancialFormulas.net_intrest_spread/2","doc":"* `intrest_income_rate` - The intrest income rate of the entity.\n* `intrest_expense_rate` - The intrest expense rate of the entity.","ref":"FinancialFormulas.html#net_intrest_spread/2-required"},{"type":"function","title":"Examples - FinancialFormulas.net_intrest_spread/2","doc":"iex> FinancialFormulas.net_intrest_spread(100, 200)\n-100","ref":"FinancialFormulas.html#net_intrest_spread/2-examples"},{"type":"function","title":"FinancialFormulas.net_present_value/3","doc":"Calculates the net present value of an investment.","ref":"FinancialFormulas.html#net_present_value/3"},{"type":"function","title":"Formula - FinancialFormulas.net_present_value/3","doc":"sum(cash_flows / (1 + discount_rate) ^ index) - initial_investment","ref":"FinancialFormulas.html#net_present_value/3-formula"},{"type":"function","title":"Required - FinancialFormulas.net_present_value/3","doc":"* `initial_investment` - The initial investment of the entity.\n* `cash_flows` - The cash flows of the entity.\n* `discount_rate` - The discount rate of the entity.","ref":"FinancialFormulas.html#net_present_value/3-required"},{"type":"function","title":"Examples - FinancialFormulas.net_present_value/3","doc":"iex> FinancialFormulas.net_present_value(100, [100, 200, 300], 0.5)\n144.44444444444443","ref":"FinancialFormulas.html#net_present_value/3-examples"},{"type":"function","title":"FinancialFormulas.net_profit_margin/2","doc":"Calculates the net profit margin of an entity.","ref":"FinancialFormulas.html#net_profit_margin/2"},{"type":"function","title":"Formula - FinancialFormulas.net_profit_margin/2","doc":"net_income / sales_revenue","ref":"FinancialFormulas.html#net_profit_margin/2-formula"},{"type":"function","title":"Required - FinancialFormulas.net_profit_margin/2","doc":"* `net_income` - The net income of the entity.\n* `sales_revenue` - The sales/revenue of the entity.","ref":"FinancialFormulas.html#net_profit_margin/2-required"},{"type":"function","title":"Examples - FinancialFormulas.net_profit_margin/2","doc":"iex> FinancialFormulas.net_profit_margin(100, 200)\n0.5","ref":"FinancialFormulas.html#net_profit_margin/2-examples"},{"type":"function","title":"FinancialFormulas.net_working_capital/2","doc":"Calculates the net working capital of an entity.","ref":"FinancialFormulas.html#net_working_capital/2"},{"type":"function","title":"Formula - FinancialFormulas.net_working_capital/2","doc":"current_assets - current_liabilities","ref":"FinancialFormulas.html#net_working_capital/2-formula"},{"type":"function","title":"Required - FinancialFormulas.net_working_capital/2","doc":"* `current_assets` - The current assets of the entity.\n* `current_liabilities` - The current liabilities of the entity.","ref":"FinancialFormulas.html#net_working_capital/2-required"},{"type":"function","title":"Examples - FinancialFormulas.net_working_capital/2","doc":"iex> FinancialFormulas.net_working_capital(100, 200)\n-100","ref":"FinancialFormulas.html#net_working_capital/2-examples"},{"type":"function","title":"FinancialFormulas.operating_cycle/2","doc":"Calculates the operating cycle of an entity.","ref":"FinancialFormulas.html#operating_cycle/2"},{"type":"function","title":"Formula - FinancialFormulas.operating_cycle/2","doc":"days_inventory_outstanding + days_sales_outstanding","ref":"FinancialFormulas.html#operating_cycle/2-formula"},{"type":"function","title":"Required - FinancialFormulas.operating_cycle/2","doc":"* `days_inventory_outstanding` - The days inventory outstanding of the entity.\n* `days_sales_outstanding` - The days sales outstanding of the entity.","ref":"FinancialFormulas.html#operating_cycle/2-required"},{"type":"function","title":"Examples - FinancialFormulas.operating_cycle/2","doc":"iex> FinancialFormulas.operating_cycle(100, 200)\n300","ref":"FinancialFormulas.html#operating_cycle/2-examples"},{"type":"function","title":"FinancialFormulas.operating_margin/2","doc":"Calculates the operating margin of an entity.","ref":"FinancialFormulas.html#operating_margin/2"},{"type":"function","title":"Formula - FinancialFormulas.operating_margin/2","doc":"operating_income / sales_revenue","ref":"FinancialFormulas.html#operating_margin/2-formula"},{"type":"function","title":"Required - FinancialFormulas.operating_margin/2","doc":"* `operating_income` - The operating income of the entity.\n* `sales_revenue` - The sales/revenue of the entity.","ref":"FinancialFormulas.html#operating_margin/2-required"},{"type":"function","title":"Examples - FinancialFormulas.operating_margin/2","doc":"iex> FinancialFormulas.operating_margin(100, 200)\n0.5","ref":"FinancialFormulas.html#operating_margin/2-examples"},{"type":"function","title":"FinancialFormulas.payables_turnover_ratio/2","doc":"Calculates the payables turnover ratio of an entity.","ref":"FinancialFormulas.html#payables_turnover_ratio/2"},{"type":"function","title":"Formula - FinancialFormulas.payables_turnover_ratio/2","doc":"cost_of_goods_sold / average_accounts_payable","ref":"FinancialFormulas.html#payables_turnover_ratio/2-formula"},{"type":"function","title":"Required - FinancialFormulas.payables_turnover_ratio/2","doc":"* `cost_of_goods_sold` - The cost of goods sold of the entity.\n* `average_accounts_payable` - The average accounts payable of the entity.","ref":"FinancialFormulas.html#payables_turnover_ratio/2-required"},{"type":"function","title":"Examples - FinancialFormulas.payables_turnover_ratio/2","doc":"iex> FinancialFormulas.payables_turnover_ratio(100, 200)\n0.5","ref":"FinancialFormulas.html#payables_turnover_ratio/2-examples"},{"type":"function","title":"FinancialFormulas.payback_period/2","doc":"Calculates the payback period of an investment.","ref":"FinancialFormulas.html#payback_period/2"},{"type":"function","title":"Formula - FinancialFormulas.payback_period/2","doc":"initial_investment / periodic_cash_flows","ref":"FinancialFormulas.html#payback_period/2-formula"},{"type":"function","title":"Required - FinancialFormulas.payback_period/2","doc":"* `initial_investment` - The initial investment of the entity.\n* `periodic_cash_flows` - The periodic cash flows of the entity.","ref":"FinancialFormulas.html#payback_period/2-required"},{"type":"function","title":"Examples - FinancialFormulas.payback_period/2","doc":"iex> FinancialFormulas.payback_period(100, 200)\n0.5","ref":"FinancialFormulas.html#payback_period/2-examples"},{"type":"function","title":"FinancialFormulas.perpetuity_yield/2","doc":"Calculates the perpetuity yield.","ref":"FinancialFormulas.html#perpetuity_yield/2"},{"type":"function","title":"Formula - FinancialFormulas.perpetuity_yield/2","doc":"payment / present_value","ref":"FinancialFormulas.html#perpetuity_yield/2-formula"},{"type":"function","title":"Required - FinancialFormulas.perpetuity_yield/2","doc":"* `payment` - The payment of the entity.\n* `present_value` - The present value of the entity.","ref":"FinancialFormulas.html#perpetuity_yield/2-required"},{"type":"function","title":"Examples - FinancialFormulas.perpetuity_yield/2","doc":"iex> FinancialFormulas.perpetuity_yield(100, 200)\n0.5","ref":"FinancialFormulas.html#perpetuity_yield/2-examples"},{"type":"function","title":"FinancialFormulas.preferred_stock_value/2","doc":"Calculates the preferred stock value.","ref":"FinancialFormulas.html#preferred_stock_value/2"},{"type":"function","title":"Formula - FinancialFormulas.preferred_stock_value/2","doc":"dividend / discount_rate","ref":"FinancialFormulas.html#preferred_stock_value/2-formula"},{"type":"function","title":"Required - FinancialFormulas.preferred_stock_value/2","doc":"* `dividend` - The dividend of the entity.\n* `discount_rate` - The discount rate of the entity.","ref":"FinancialFormulas.html#preferred_stock_value/2-required"},{"type":"function","title":"Examples - FinancialFormulas.preferred_stock_value/2","doc":"iex> FinancialFormulas.preferred_stock_value(100, 200)\n0.5","ref":"FinancialFormulas.html#preferred_stock_value/2-examples"},{"type":"function","title":"FinancialFormulas.present_value/3","doc":"Calculates the present value.","ref":"FinancialFormulas.html#present_value/3"},{"type":"function","title":"Formula - FinancialFormulas.present_value/3","doc":"cash_flow / (1 + rate_of_return) ^ number_of_periods","ref":"FinancialFormulas.html#present_value/3-formula"},{"type":"function","title":"Required - FinancialFormulas.present_value/3","doc":"* `future_value` - The future value of the entity.\n* `rate_of_return` - The rate of return of the entity.\n* `number_of_periods` - The number of periods of the entity.","ref":"FinancialFormulas.html#present_value/3-required"},{"type":"function","title":"Examples - FinancialFormulas.present_value/3","doc":"iex> FinancialFormulas.present_value(100, 200, 1)\n0.4975124378109453","ref":"FinancialFormulas.html#present_value/3-examples"},{"type":"function","title":"FinancialFormulas.present_value_continuous_compounding/3","doc":"Calculates prevent value with continuous compounding.","ref":"FinancialFormulas.html#present_value_continuous_compounding/3"},{"type":"function","title":"Formula - FinancialFormulas.present_value_continuous_compounding/3","doc":"cash_flow / e ^ (rate * time)","ref":"FinancialFormulas.html#present_value_continuous_compounding/3-formula"},{"type":"function","title":"Required - FinancialFormulas.present_value_continuous_compounding/3","doc":"* `future_value` - The future value of the entity.\n* `rate_of_return` - The rate of return of the entity.\n* `time` - The number of periods of the entity.","ref":"FinancialFormulas.html#present_value_continuous_compounding/3-required"},{"type":"function","title":"Examples - FinancialFormulas.present_value_continuous_compounding/3","doc":"iex> FinancialFormulas.present_value_continuous_compounding(1, 2, 1)\n0.1353352832366127","ref":"FinancialFormulas.html#present_value_continuous_compounding/3-examples"},{"type":"function","title":"FinancialFormulas.present_value_of_perpetuity/2","doc":"Calculates the present value of perpetuity.","ref":"FinancialFormulas.html#present_value_of_perpetuity/2"},{"type":"function","title":"Formula - FinancialFormulas.present_value_of_perpetuity/2","doc":"coupon_per_period / discount_rate","ref":"FinancialFormulas.html#present_value_of_perpetuity/2-formula"},{"type":"function","title":"Required - FinancialFormulas.present_value_of_perpetuity/2","doc":"* `coupon_per_period` - The coupon per period of the entity.\n* `discount_rate` - The discount rate of the entity.","ref":"FinancialFormulas.html#present_value_of_perpetuity/2-required"},{"type":"function","title":"Examples - FinancialFormulas.present_value_of_perpetuity/2","doc":"iex> FinancialFormulas.present_value_of_perpetuity(100, 200)\n0.5","ref":"FinancialFormulas.html#present_value_of_perpetuity/2-examples"},{"type":"function","title":"FinancialFormulas.price_to_book_value/2","doc":"Calculates the price to book value.","ref":"FinancialFormulas.html#price_to_book_value/2"},{"type":"function","title":"Formula - FinancialFormulas.price_to_book_value/2","doc":"price_per_share / book_value_per_share","ref":"FinancialFormulas.html#price_to_book_value/2-formula"},{"type":"function","title":"Required - FinancialFormulas.price_to_book_value/2","doc":"* `price_per_share` - The price per share of the entity.\n* `book_value_per_share` - The book value per share of the entity.","ref":"FinancialFormulas.html#price_to_book_value/2-required"},{"type":"function","title":"Examples - FinancialFormulas.price_to_book_value/2","doc":"iex> FinancialFormulas.price_to_book_value(100, 200)\n0.5","ref":"FinancialFormulas.html#price_to_book_value/2-examples"},{"type":"function","title":"FinancialFormulas.price_to_cash_flow/2","doc":"Calculates the price to cash flow.","ref":"FinancialFormulas.html#price_to_cash_flow/2"},{"type":"function","title":"Formula - FinancialFormulas.price_to_cash_flow/2","doc":"market_capitalization / cash_flow","ref":"FinancialFormulas.html#price_to_cash_flow/2-formula"},{"type":"function","title":"Required - FinancialFormulas.price_to_cash_flow/2","doc":"* `market_capitalization` - The market capitalization of the entity.\n* `cash_flow` - The cash flow of the entity.","ref":"FinancialFormulas.html#price_to_cash_flow/2-required"},{"type":"function","title":"Examples - FinancialFormulas.price_to_cash_flow/2","doc":"iex> FinancialFormulas.price_to_cash_flow(100, 200)\n0.5","ref":"FinancialFormulas.html#price_to_cash_flow/2-examples"},{"type":"function","title":"FinancialFormulas.price_to_dividend_ratio/2","doc":"Calculates the price to dividend ratio.","ref":"FinancialFormulas.html#price_to_dividend_ratio/2"},{"type":"function","title":"Formula - FinancialFormulas.price_to_dividend_ratio/2","doc":"price_per_share / dividend_per_share","ref":"FinancialFormulas.html#price_to_dividend_ratio/2-formula"},{"type":"function","title":"Required - FinancialFormulas.price_to_dividend_ratio/2","doc":"* `price_per_share` - The price per share of the entity.\n* `dividend_per_share` - The dividend per share of the entity.","ref":"FinancialFormulas.html#price_to_dividend_ratio/2-required"},{"type":"function","title":"Examples - FinancialFormulas.price_to_dividend_ratio/2","doc":"iex> FinancialFormulas.price_to_dividend_ratio(100, 200)\n0.5","ref":"FinancialFormulas.html#price_to_dividend_ratio/2-examples"},{"type":"function","title":"FinancialFormulas.price_to_earnings_ratio/2","doc":"Calculates the price to earnings ratio.","ref":"FinancialFormulas.html#price_to_earnings_ratio/2"},{"type":"function","title":"Formula - FinancialFormulas.price_to_earnings_ratio/2","doc":"price_per_share / earnings_per_share","ref":"FinancialFormulas.html#price_to_earnings_ratio/2-formula"},{"type":"function","title":"Required - FinancialFormulas.price_to_earnings_ratio/2","doc":"* `price_per_share` - The price per share of the entity.\n* `earnings_per_share` - The earnings per share of the entity.","ref":"FinancialFormulas.html#price_to_earnings_ratio/2-required"},{"type":"function","title":"Examples - FinancialFormulas.price_to_earnings_ratio/2","doc":"iex> FinancialFormulas.price_to_earnings_ratio(100, 200)\n0.5","ref":"FinancialFormulas.html#price_to_earnings_ratio/2-examples"},{"type":"function","title":"FinancialFormulas.price_to_sales_ratio/2","doc":"Calculates the price to sales ratio.","ref":"FinancialFormulas.html#price_to_sales_ratio/2"},{"type":"function","title":"Formula - FinancialFormulas.price_to_sales_ratio/2","doc":"price_per_share / sales_per_share","ref":"FinancialFormulas.html#price_to_sales_ratio/2-formula"},{"type":"function","title":"Required - FinancialFormulas.price_to_sales_ratio/2","doc":"* `price_per_share` - The price per share of the entity.\n* `sales_per_share` - The sales per share of the entity.","ref":"FinancialFormulas.html#price_to_sales_ratio/2-required"},{"type":"function","title":"Examples - FinancialFormulas.price_to_sales_ratio/2","doc":"iex> FinancialFormulas.price_to_sales_ratio(100, 200)\n0.5","ref":"FinancialFormulas.html#price_to_sales_ratio/2-examples"},{"type":"function","title":"FinancialFormulas.profitability_index/2","doc":"Calculates the profitability index.","ref":"FinancialFormulas.html#profitability_index/2"},{"type":"function","title":"Formula - FinancialFormulas.profitability_index/2","doc":"present_value_of_future_cash_flows / initial_investment","ref":"FinancialFormulas.html#profitability_index/2-formula"},{"type":"function","title":"Required - FinancialFormulas.profitability_index/2","doc":"* `present_value_of_future_cash_flows` - The present value of future cash flows of the entity.\n* `initial_investment` - The initial investment of the entity.","ref":"FinancialFormulas.html#profitability_index/2-required"},{"type":"function","title":"Examples - FinancialFormulas.profitability_index/2","doc":"iex> FinancialFormulas.profitability_index(100, 200)\n0.5","ref":"FinancialFormulas.html#profitability_index/2-examples"},{"type":"function","title":"FinancialFormulas.quick_ratio/2","doc":"Calculates the quick ratio.","ref":"FinancialFormulas.html#quick_ratio/2"},{"type":"function","title":"Formula - FinancialFormulas.quick_ratio/2","doc":"quick_assets / current_liabilities","ref":"FinancialFormulas.html#quick_ratio/2-formula"},{"type":"function","title":"Required - FinancialFormulas.quick_ratio/2","doc":"* `quick_assets` - The quick assets of the entity.\n* `current_liabilities` - The current liabilities of the entity.","ref":"FinancialFormulas.html#quick_ratio/2-required"},{"type":"function","title":"Examples - FinancialFormulas.quick_ratio/2","doc":"iex> FinancialFormulas.quick_ratio(100, 200)\n0.5","ref":"FinancialFormulas.html#quick_ratio/2-examples"},{"type":"function","title":"FinancialFormulas.quick_ratio/3","doc":"Calculates the quick ratio.","ref":"FinancialFormulas.html#quick_ratio/3"},{"type":"function","title":"Formula - FinancialFormulas.quick_ratio/3","doc":"(current_assets - inventory) / current_liabilities","ref":"FinancialFormulas.html#quick_ratio/3-formula"},{"type":"function","title":"Required - FinancialFormulas.quick_ratio/3","doc":"* `current_assets` - The current assets of the entity.\n* `inventory` - The inventory of the entity.\n* `current_liabilities` - The current liabilities of the entity.","ref":"FinancialFormulas.html#quick_ratio/3-required"},{"type":"function","title":"Examples - FinancialFormulas.quick_ratio/3","doc":"iex> FinancialFormulas.quick_ratio(100, 200, 300)\n-0.3333333333333333","ref":"FinancialFormulas.html#quick_ratio/3-examples"},{"type":"function","title":"FinancialFormulas.real_gdp/2","doc":"Calculates the real GDP.","ref":"FinancialFormulas.html#real_gdp/2"},{"type":"function","title":"Formula - FinancialFormulas.real_gdp/2","doc":"nominal_gdp / gdp_deflator","ref":"FinancialFormulas.html#real_gdp/2-formula"},{"type":"function","title":"Required - FinancialFormulas.real_gdp/2","doc":"* `nominal_gdp` - The nominal GDP.\n* `gdp_deflator` - The GDP deflator.","ref":"FinancialFormulas.html#real_gdp/2-required"},{"type":"function","title":"Examples - FinancialFormulas.real_gdp/2","doc":"iex> FinancialFormulas.real_gdp(100, 200)\n0.5","ref":"FinancialFormulas.html#real_gdp/2-examples"},{"type":"function","title":"FinancialFormulas.receivables_turnover_ratio/2","doc":"Calculates the receivables turnover ratio of an entity.","ref":"FinancialFormulas.html#receivables_turnover_ratio/2"},{"type":"function","title":"Formula - FinancialFormulas.receivables_turnover_ratio/2","doc":"net_credit_sales / average_accounts_receivable","ref":"FinancialFormulas.html#receivables_turnover_ratio/2-formula"},{"type":"function","title":"Required - FinancialFormulas.receivables_turnover_ratio/2","doc":"* `net_credit_sales` - The net credit sales of the entity.\n* `average_accounts_receivable` - The average accounts receivable of the entity.","ref":"FinancialFormulas.html#receivables_turnover_ratio/2-required"},{"type":"function","title":"Examples - FinancialFormulas.receivables_turnover_ratio/2","doc":"iex> FinancialFormulas.receivables_turnover_ratio(100, 200)\n0.5","ref":"FinancialFormulas.html#receivables_turnover_ratio/2-examples"},{"type":"function","title":"FinancialFormulas.retained_earnings/2","doc":"Calculates the retained earnings of an entity.","ref":"FinancialFormulas.html#retained_earnings/2"},{"type":"function","title":"Formula - FinancialFormulas.retained_earnings/2","doc":"net_income - dividends","ref":"FinancialFormulas.html#retained_earnings/2-formula"},{"type":"function","title":"Required - FinancialFormulas.retained_earnings/2","doc":"* `net_income` - The net income of the entity.\n* `dividends` - The dividends of the entity.","ref":"FinancialFormulas.html#retained_earnings/2-required"},{"type":"function","title":"Examples - FinancialFormulas.retained_earnings/2","doc":"iex> FinancialFormulas.retained_earnings(100, 200)\n-100","ref":"FinancialFormulas.html#retained_earnings/2-examples"},{"type":"function","title":"FinancialFormulas.retention_ratio/2","doc":"Calculates the retention ratio.","ref":"FinancialFormulas.html#retention_ratio/2"},{"type":"function","title":"Formula - FinancialFormulas.retention_ratio/2","doc":"(net_income - dividends) / net_income","ref":"FinancialFormulas.html#retention_ratio/2-formula"},{"type":"function","title":"Required - FinancialFormulas.retention_ratio/2","doc":"* `net_income` - The net income of the entity.\n* `dividends` - The dividends of the entity.","ref":"FinancialFormulas.html#retention_ratio/2-required"},{"type":"function","title":"Examples - FinancialFormulas.retention_ratio/2","doc":"iex> FinancialFormulas.retention_ratio(100, 200)\n-1.0","ref":"FinancialFormulas.html#retention_ratio/2-examples"},{"type":"function","title":"FinancialFormulas.return_on_assets/2","doc":"Calculates the return on assets.","ref":"FinancialFormulas.html#return_on_assets/2"},{"type":"function","title":"Formula - FinancialFormulas.return_on_assets/2","doc":"net_income / average_total_assets","ref":"FinancialFormulas.html#return_on_assets/2-formula"},{"type":"function","title":"Required - FinancialFormulas.return_on_assets/2","doc":"* `net_income` - The net income of the entity.\n* `average_total_assets` - The average total assets of the entity.","ref":"FinancialFormulas.html#return_on_assets/2-required"},{"type":"function","title":"Examples - FinancialFormulas.return_on_assets/2","doc":"iex> FinancialFormulas.return_on_assets(100, 200)\n0.5","ref":"FinancialFormulas.html#return_on_assets/2-examples"},{"type":"function","title":"FinancialFormulas.return_on_equity/2","doc":"Calculates the return on equity.","ref":"FinancialFormulas.html#return_on_equity/2"},{"type":"function","title":"Formula - FinancialFormulas.return_on_equity/2","doc":"net_income / average_shareholder_equity","ref":"FinancialFormulas.html#return_on_equity/2-formula"},{"type":"function","title":"Required - FinancialFormulas.return_on_equity/2","doc":"* `net_income` - The net income of the entity.\n* `average_shareholder_equity` - The average shareholder equity of the entity.","ref":"FinancialFormulas.html#return_on_equity/2-required"},{"type":"function","title":"Examples - FinancialFormulas.return_on_equity/2","doc":"iex> FinancialFormulas.return_on_equity(100, 200)\n0.5","ref":"FinancialFormulas.html#return_on_equity/2-examples"},{"type":"function","title":"FinancialFormulas.return_on_investment/2","doc":"Calculates the return on investment.","ref":"FinancialFormulas.html#return_on_investment/2"},{"type":"function","title":"Formula - FinancialFormulas.return_on_investment/2","doc":"(earnings - initial_investment) / initial_investment","ref":"FinancialFormulas.html#return_on_investment/2-formula"},{"type":"function","title":"Required - FinancialFormulas.return_on_investment/2","doc":"* `initial_investment` - The initial investment of the entity.\n* `earnings` - The earnings of the entity.","ref":"FinancialFormulas.html#return_on_investment/2-required"},{"type":"function","title":"Examples - FinancialFormulas.return_on_investment/2","doc":"iex> FinancialFormulas.return_on_investment(100, 200)\n1.0","ref":"FinancialFormulas.html#return_on_investment/2-examples"},{"type":"function","title":"FinancialFormulas.risk_premium/2","doc":"Calculates the risk premium.","ref":"FinancialFormulas.html#risk_premium/2"},{"type":"function","title":"Formula - FinancialFormulas.risk_premium/2","doc":"asset_or_investment_return - risk_free_return","ref":"FinancialFormulas.html#risk_premium/2-formula"},{"type":"function","title":"Required - FinancialFormulas.risk_premium/2","doc":"* `asset_or_investment_return` - The asset or investment return.\n* `risk_free_return` - The risk free return.","ref":"FinancialFormulas.html#risk_premium/2-required"},{"type":"function","title":"Examples - FinancialFormulas.risk_premium/2","doc":"iex> FinancialFormulas.risk_premium(100, 200)\n-100","ref":"FinancialFormulas.html#risk_premium/2-examples"},{"type":"function","title":"FinancialFormulas.rule_of_72/1","doc":"Calculates the rule of 72.","ref":"FinancialFormulas.html#rule_of_72/1"},{"type":"function","title":"Formula - FinancialFormulas.rule_of_72/1","doc":"72 / rate_of_return","ref":"FinancialFormulas.html#rule_of_72/1-formula"},{"type":"function","title":"Required - FinancialFormulas.rule_of_72/1","doc":"* `rate_of_return` - The rate of return as a whole number.","ref":"FinancialFormulas.html#rule_of_72/1-required"},{"type":"function","title":"Examples - FinancialFormulas.rule_of_72/1","doc":"iex> FinancialFormulas.rule_of_72(100)\n0.72","ref":"FinancialFormulas.html#rule_of_72/1-examples"},{"type":"function","title":"FinancialFormulas.simple_interest/3","doc":"Calculates the simple interest.","ref":"FinancialFormulas.html#simple_interest/3"},{"type":"function","title":"Formula - FinancialFormulas.simple_interest/3","doc":"principal * interest_rate * time","ref":"FinancialFormulas.html#simple_interest/3-formula"},{"type":"function","title":"Required - FinancialFormulas.simple_interest/3","doc":"* `principal` - The principal amount.\n* `interest_rate` - The interest rate.\n* `time` - The time.","ref":"FinancialFormulas.html#simple_interest/3-required"},{"type":"function","title":"Examples - FinancialFormulas.simple_interest/3","doc":"iex> FinancialFormulas.simple_interest(100, 200, 300)\n6000000","ref":"FinancialFormulas.html#simple_interest/3-examples"},{"type":"function","title":"FinancialFormulas.straight_line_depreciation/3","doc":"Calculates the straight line depreciation.","ref":"FinancialFormulas.html#straight_line_depreciation/3"},{"type":"function","title":"Formula - FinancialFormulas.straight_line_depreciation/3","doc":"(initial_value - salvage_value) / useful_life","ref":"FinancialFormulas.html#straight_line_depreciation/3-formula"},{"type":"function","title":"Required - FinancialFormulas.straight_line_depreciation/3","doc":"* `initial_value` - The initial value.\n* `salvage_value` - The salvage value.\n* `useful_life` - The useful life.","ref":"FinancialFormulas.html#straight_line_depreciation/3-required"},{"type":"function","title":"Examples - FinancialFormulas.straight_line_depreciation/3","doc":"iex> FinancialFormulas.straight_line_depreciation(100, 200, 300)\n-0.3333333333333333","ref":"FinancialFormulas.html#straight_line_depreciation/3-examples"},{"type":"function","title":"FinancialFormulas.tax_equivalent_yield/2","doc":"Calculates the tax equivalent yield.","ref":"FinancialFormulas.html#tax_equivalent_yield/2"},{"type":"function","title":"Formula - FinancialFormulas.tax_equivalent_yield/2","doc":"tax_free_yield / (1 - tax_rate)","ref":"FinancialFormulas.html#tax_equivalent_yield/2-formula"},{"type":"function","title":"Required - FinancialFormulas.tax_equivalent_yield/2","doc":"* `tax_free_yield` - The tax free yield.\n* `tax_rate` - The tax rate.","ref":"FinancialFormulas.html#tax_equivalent_yield/2-required"},{"type":"function","title":"Examples - FinancialFormulas.tax_equivalent_yield/2","doc":"iex> FinancialFormulas.tax_equivalent_yield(100, 200)\n-0.5025125628140703","ref":"FinancialFormulas.html#tax_equivalent_yield/2-examples"},{"type":"function","title":"FinancialFormulas.times_interest_earned_ratio/2","doc":"Calculates the times interest earned ratio.","ref":"FinancialFormulas.html#times_interest_earned_ratio/2"},{"type":"function","title":"Formula - FinancialFormulas.times_interest_earned_ratio/2","doc":"ebit / interest_expense","ref":"FinancialFormulas.html#times_interest_earned_ratio/2-formula"},{"type":"function","title":"Required - FinancialFormulas.times_interest_earned_ratio/2","doc":"* `ebit` - The earnings before interest and taxes of the entity.\n* `interest_expense` - The interest expense of the entity.","ref":"FinancialFormulas.html#times_interest_earned_ratio/2-required"},{"type":"function","title":"Examples - FinancialFormulas.times_interest_earned_ratio/2","doc":"iex> FinancialFormulas.times_interest_earned_ratio(100, 200)\n0.5","ref":"FinancialFormulas.html#times_interest_earned_ratio/2-examples"},{"type":"function","title":"FinancialFormulas.to_percentage/1","doc":"Transforms a number to a percentage.","ref":"FinancialFormulas.html#to_percentage/1"},{"type":"function","title":"Required - FinancialFormulas.to_percentage/1","doc":"* `number` - The number to transform.","ref":"FinancialFormulas.html#to_percentage/1-required"},{"type":"function","title":"FinancialFormulas.total_stock_return/3","doc":"Calculates the total stock return.","ref":"FinancialFormulas.html#total_stock_return/3"},{"type":"function","title":"Formula - FinancialFormulas.total_stock_return/3","doc":"(ending_stock_price - initial_stock_price + dividends) / initial_stock_price","ref":"FinancialFormulas.html#total_stock_return/3-formula"},{"type":"function","title":"Required - FinancialFormulas.total_stock_return/3","doc":"* `initial_stock_price` - The initial stock price.\n* `ending_stock_price` - The ending stock price.\n* `dividends` - The dividends.","ref":"FinancialFormulas.html#total_stock_return/3-required"},{"type":"function","title":"Examples - FinancialFormulas.total_stock_return/3","doc":"iex> FinancialFormulas.total_stock_return(100, 200, 50)\n1.5","ref":"FinancialFormulas.html#total_stock_return/3-examples"},{"type":"function","title":"FinancialFormulas.weighted_average/1","doc":"Calculates the weighted average.","ref":"FinancialFormulas.html#weighted_average/1"},{"type":"function","title":"Formula - FinancialFormulas.weighted_average/1","doc":"(weight1 * value1) + (weight2 * value2) + ... + (weightN * valueN)","ref":"FinancialFormulas.html#weighted_average/1-formula"},{"type":"function","title":"Required - FinancialFormulas.weighted_average/1","doc":"* `list` - The list of weights and values.","ref":"FinancialFormulas.html#weighted_average/1-required"},{"type":"function","title":"Examples - FinancialFormulas.weighted_average/1","doc":"iex> FinancialFormulas.weighted_average([{0.5, 100}, {0.5, 200}])\n150.0","ref":"FinancialFormulas.html#weighted_average/1-examples"},{"type":"function","title":"FinancialFormulas.year_over_year/2","doc":"Calculates the year over year growth rate.","ref":"FinancialFormulas.html#year_over_year/2"},{"type":"function","title":"Formula - FinancialFormulas.year_over_year/2","doc":"(current_year - previous_year) / previous_year","ref":"FinancialFormulas.html#year_over_year/2-formula"},{"type":"function","title":"Required - FinancialFormulas.year_over_year/2","doc":"* `current_year` - The current year value\n* `previous_year` - The previous year value","ref":"FinancialFormulas.html#year_over_year/2-required"},{"type":"function","title":"Examples - FinancialFormulas.year_over_year/2","doc":"iex> FinancialFormulas.year_over_year(100, 200)\n-0.5","ref":"FinancialFormulas.html#year_over_year/2-examples"}],"content_type":"text/markdown"}